@@ -21,7 +21,7 @@ if PY2:
 
 dna_bases = re.compile(r'([ACTGNactgnYRWSKMDVHBXyrwskmdvhbx]+)')
 
-__version__ = '0.3.6'
+__version__ = '0.3.7.1'
 
 
 class FastaIndexingError(Exception):
@@ -204,7 +204,7 @@ class Faidx(object):
 
         self.mutable = mutable
 
-        if os.path.exists(self.indexname) and getmtime(self.indexname) > getmtime(self.filename):
+        if os.path.exists(self.indexname) and getmtime(self.indexname) >= getmtime(self.filename):
             self.read_fai(split_char)
         else:
             try:
@@ -444,9 +444,9 @@ class FastaRecord(object):
         try:
             if isinstance(n, slice):
                 start, stop, step = n.start, n.stop, n.step
-                if not start:
+                if start is None:
                     start = 0
-                if not stop:
+                if stop is None:
                     stop = len(self)
                 if stop < 0:
                     stop = len(self) + stop
@@ -483,6 +483,20 @@ class FastaRecord(object):
     def __str__(self):
         return str(self[:])
 
+    @property
+    def long_name(self):
+        """ Read the actual defline from self._fa.faidx mdshw5/pyfaidx#54 """
+        seqnames = tuple(self._fa.keys())
+        seqname_i = seqnames.index(self.name)
+        if seqname_i > 0:
+            seqname_p = seqnames[seqname_i - 1]  # previous seqname
+            _, internals = self._fa.faidx.from_file(seqname_p, 1, 1, internals=True)
+            defline_start = internals['bend'] + 1
+        elif seqname_i == 0:
+            defline_start = 0
+        defline_end = self._fa.faidx.index[self.name].offset
+        self._fa.faidx.file.seek(defline_start)
+        return self._fa.faidx.file.read(defline_end - defline_start).decode()[1:-1]
 
 class MutableFastaRecord(FastaRecord):
     def __init__(self, name, fa):
